# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: IssuingAttributes.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='IssuingAttributes.proto',
  package='sharepubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\026IssuingAttributesProtoZ\016yotiprotoshare\252\002\030Yoti.Auth.ProtoBuf.Share\312\002\020Yoti\\Sharepubapi\342\002\034Yoti\\Sharepubapi\\GPBMetadata\352\002\031Yoti.Protobuf.Sharepubapi'),
  serialized_pb=_b('\n\x17IssuingAttributes.proto\x12\x0esharepubapi_v1\"Y\n\x11IssuingAttributes\x12\x13\n\x0b\x65xpiry_date\x18\x01 \x01(\t\x12/\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32\x1a.sharepubapi_v1.Definition\"\x1a\n\nDefinition\x12\x0c\n\x04name\x18\x01 \x01(\tB\xb7\x01\n$com.yoti.api.client.spi.remote.protoB\x16IssuingAttributesProtoZ\x0eyotiprotoshare\xaa\x02\x18Yoti.Auth.ProtoBuf.Share\xca\x02\x10Yoti\\Sharepubapi\xe2\x02\x1cYoti\\Sharepubapi\\GPBMetadata\xea\x02\x19Yoti.Protobuf.Sharepubapib\x06proto3')
)




_ISSUINGATTRIBUTES = _descriptor.Descriptor(
  name='IssuingAttributes',
  full_name='sharepubapi_v1.IssuingAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expiry_date', full_name='sharepubapi_v1.IssuingAttributes.expiry_date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='definitions', full_name='sharepubapi_v1.IssuingAttributes.definitions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=132,
)


_DEFINITION = _descriptor.Descriptor(
  name='Definition',
  full_name='sharepubapi_v1.Definition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sharepubapi_v1.Definition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=160,
)

_ISSUINGATTRIBUTES.fields_by_name['definitions'].message_type = _DEFINITION
DESCRIPTOR.message_types_by_name['IssuingAttributes'] = _ISSUINGATTRIBUTES
DESCRIPTOR.message_types_by_name['Definition'] = _DEFINITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IssuingAttributes = _reflection.GeneratedProtocolMessageType('IssuingAttributes', (_message.Message,), dict(
  DESCRIPTOR = _ISSUINGATTRIBUTES,
  __module__ = 'IssuingAttributes_pb2'
  # @@protoc_insertion_point(class_scope:sharepubapi_v1.IssuingAttributes)
  ))
_sym_db.RegisterMessage(IssuingAttributes)

Definition = _reflection.GeneratedProtocolMessageType('Definition', (_message.Message,), dict(
  DESCRIPTOR = _DEFINITION,
  __module__ = 'IssuingAttributes_pb2'
  # @@protoc_insertion_point(class_scope:sharepubapi_v1.Definition)
  ))
_sym_db.RegisterMessage(Definition)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
