# -*- coding: utf-8 -*-
from __future__ import unicode_literals

ID_DOCUMENT_AUTHENTICITY = "ID_DOCUMENT_AUTHENTICITY"
ID_DOCUMENT_TEXT_DATA_CHECK = "ID_DOCUMENT_TEXT_DATA_CHECK"
ID_DOCUMENT_TEXT_DATA_EXTRACTION = "ID_DOCUMENT_TEXT_DATA_EXTRACTION"
ID_DOCUMENT_FACE_MATCH = "ID_DOCUMENT_FACE_MATCH"
LIVENESS = "LIVENESS"
ZOOM = "ZOOM"

CAMERA = "CAMERA"
CAMERA_AND_UPLOAD = "CAMERA_AND_UPLOAD"

RESOURCE_UPDATE = "RESOURCE_UPDATE"
TASK_COMPLETION = "TASK_COMPLETION"
CHECK_COMPLETION = "CHECK_COMPLETION"
SESSION_COMPLETION = "SESSION_COMPLETION"

ALWAYS = "ALWAYS"
FALLBACK = "FALLBACK"
NEVER = "NEVER"
